
# Does democratic governance inhibit vaccination?

# initialize server
rm(list=ls())
# setwd("/pol300")
library(tidyverse)

covid <- read.csv("owid-covid-data.csv")                             # load covid data
#browseURL(url = "https://ourworldindata.org/covid-vaccinations")     # where the data come from
library(vdemdata)                                                    # need VDEM for democracy data
vdem %>%                                                             # year 2018 only (latest democracy data)
  filter(year==2018) ->
  vdem.s

# what countries from the COVID set do we have in VDEM?
unique(covid$location[covid$iso_code %in% vdem.s$country_text_id])
`%notin%` <- Negate(`%in%`)
# what countries from the COVID set do we NOT have in VDEM?
unique(covid$location[covid$iso_code %notin% vdem.s$country_text_id])

# what countries from the VDEM set do we not have in COVID?
unique(vdem.s$country_name[vdem.s$country_text_id %notin% covid$iso_code])
vdem.s.small <- vdem.s %>% select(country_text_id, e_polity2)

# what's the latest date for which data is available?
covid.s <- covid %>% 
  filter(!is.na(people_vaccinated_per_hundred)) %>%
  group_by(location) %>%
  filter(date == max(date)) 

# dates of availability
print(covid.s[order(covid.s$date),c("date", "location", 
                                    "people_vaccinated_per_hundred")], n=226)

# filter out any countries with data before July
covid.s <- covid %>% 
  filter(!is.na(people_vaccinated_per_hundred)) %>%
  group_by(location) %>%
  filter(date == max(date)) %>%
  filter(date > lubridate::ymd("2021-08-01"))

# re-check dates of availability
print(covid.s[order(covid.s$date),c("date", "location", 
                                    "people_vaccinated_per_hundred")], n=226)

# merge the two data sets
covid.m <- left_join(covid.s, vdem.s.small, by=c("iso_code" = "country_text_id"))

# classify some countries as democracy
covid.m$democracy <- covid.m$e_polity2 >= 6

# create small plot data set with only the variables we use
# and omitting democracy missing values
covid.plot <- covid.m %>% 
  filter(is.na(democracy) == F) %>% 
  select(people_vaccinated_per_hundred, democracy, gdp_per_capita, location)

na.omit(covid.plot)$location

# basic plot
ggplot(covid.plot, aes(y=people_vaccinated_per_hundred/100, x=democracy)) +
  geom_boxplot(fill="lightgray") + theme_bw() + xlab("democracy") + ylab("% of people vaccinated") +
  scale_y_continuous(labels = scales::percent_format()) 

# first bivariate plot
ggplot(covid.plot, aes(y=people_vaccinated_per_hundred, x=gdp_per_capita, color=democracy)) +
  geom_point()

# improved aesthetics--but be careful with na.omit!! with great power
# comes great responsibility not to accidentally drop 90% of the data set
ggplot(na.omit(covid.plot), aes(y=people_vaccinated_per_hundred/100, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() + scale_y_continuous(labels = scales::percent_format()) +
  scale_x_continuous(labels = scales::dollar_format()) +
  xlab("GDP per Capita") + ylab("% Vaccinated") + geom_smooth(method="lm", formula=y~x, se=F) +
  ggtitle(label = "Worldwide Vaccination Rates", subtitle = paste("as of ", max(covid.m$date), 
                                                                  " (using latest available data newer than 2021-08-01)", sep=""))

ggplot(na.omit(covid.plot), aes(y=people_vaccinated_per_hundred/100, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() + scale_y_continuous(labels = scales::percent_format()) +
  scale_x_log10(labels = c("< $1.00", "$10.00", "$100.00", "$1,000", "$10,000",
                           "$25,000", "$50,000", "$100,000"), 
                breaks=c(1, 10, 100, 1000, 10000, 25000, 50000, 100000)) +
  xlab("GDP per Capita (log scale)") + ylab("% Vaccinated") + geom_smooth(method="glm", formula=y ~ x, se=F, method.args = list(family="quasibinomial")) +
  ggtitle(label = "Worldwide Vaccination Rates", subtitle = paste("as of ", max(covid.m$date), 
                                                                  " (using latest available data after 2021-08-01)", sep=""))
















# RoW democracy measure

# initialize server
rm(list=ls())
# setwd("/pol300")
library(tidyverse)

covid <- read.csv("owid-covid-data.csv")                             # load covid data
#browseURL(url = "https://ourworldindata.org/covid-vaccinations")     # where the data come from
library(vdemdata)                                                    # need VDEM for democracy data
vdem %>%                                                             # year 2020 only (latest democracy data)
  filter(year==2020) ->
  vdem.s

# what countries from the COVID set do we have in VDEM?
unique(covid$location[covid$iso_code %in% vdem.s$country_text_id])
`%notin%` <- Negate(`%in%`)
# what countries from the COVID set do we NOT have in VDEM?
unique(covid$location[covid$iso_code %notin% vdem.s$country_text_id])

# what countries from the VDEM set do we not have in COVID?
unique(vdem.s$country_name[vdem.s$country_text_id %notin% covid$iso_code])
vdem.s.small <- vdem.s %>% select(country_text_id, v2x_regime)

# what's the latest date for which data is available?
covid.s <- covid %>% 
  filter(!is.na(people_vaccinated_per_hundred)) %>%
  group_by(location) %>%
  filter(date == max(date)) 

# dates of availability
print(covid.s[order(covid.s$date),c("date", "location", 
                                    "people_vaccinated_per_hundred")], n=226)

# filter out any countries with data before July
covid.s <- covid %>% 
  filter(!is.na(people_vaccinated_per_hundred)) %>%
  group_by(location) %>%
  filter(date == max(date)) %>%
  filter(date > lubridate::ymd("2021-08-01"))

# re-check dates of availability
print(covid.s[order(covid.s$date),c("date", "location", 
                                    "people_vaccinated_per_hundred")], n=226)

# merge the two data sets
covid.m <- left_join(covid.s, vdem.s.small, by=c("iso_code" = "country_text_id"))

# classify some countries as democracy
covid.m$democracy <- factor(covid.m$v2x_regime >= 2, 
                            levels=c(FALSE,TRUE), labels=c("dictatorship", "democracy"))
table(covid.m$democracy)
plot(democracy ~ v2x_regime, data=covid.m)
na.omit(covid.m$location[covid.m$democracy=="democracy"])
na.omit(covid.m$location[covid.m$democracy=="dictatorship"])

# create small plot data set with only the variables we use
# and omitting democracy missing values
covid.plot <- covid.m %>% 
  filter(is.na(democracy) == F) %>% 
  select(people_vaccinated_per_hundred, democracy, gdp_per_capita, location)

na.omit(covid.plot)$location

# basic plot
ggplot(covid.plot, aes(y=people_vaccinated_per_hundred/100, x=democracy)) +
  geom_boxplot(fill="lightgray") + theme_bw() + xlab("democracy") + ylab("% of people vaccinated") +
  scale_y_continuous(labels = scales::percent_format()) 

# first bivariate plot
ggplot(covid.plot, aes(y=people_vaccinated_per_hundred, x=gdp_per_capita, color=democracy)) +
  geom_point()

# improved aesthetics--but be careful with na.omit!! with great power
# comes great responsibility not to accidentally drop 90% of the data set
ggplot(na.omit(covid.plot), aes(y=people_vaccinated_per_hundred/100, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() + scale_y_continuous(labels = scales::percent_format()) +
  scale_x_continuous(labels = scales::dollar_format()) +
  xlab("GDP per Capita") + ylab("% Vaccinated") + geom_smooth(method="lm", formula=y~x, se=F) +
  ggtitle(label = "Worldwide Vaccination Rates", subtitle = paste("as of ", max(covid.m$date), 
                                                                  " (using latest available data newer than 2021-08-01)", sep=""))

pdf(file="row-democracy-vaccine.pdf", height=6.5, width = 6)
ggplot(na.omit(covid.plot), aes(y=people_vaccinated_per_hundred/100, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() + scale_y_continuous(labels = scales::percent_format()) +
  scale_x_log10(labels = c("< $1.00", "$10.00", "$100.00", "$1,000", "$10,000",
                           "$25,000", "$50,000", "$100,000"), 
                breaks=c(1, 10, 100, 1000, 10000, 25000, 50000, 100000)) +
  xlab("GDP per Capita (log scale)") + ylab("Percentage of population with at least one dose of vaccine") + 
  geom_smooth(method="glm", formula=y ~ x, se=F, method.args = list(family="quasibinomial")) +
  ggtitle(label = "Worldwide Vaccination Rates", 
#         subtitle = paste("As of ", max(covid.m$date), " (using latest available data after 2021-08-01)", sep="")) +
          subtitle = "As of September 14, 2021 (using latest available data after August 1, 2021)") +
  guides(color = guide_legend(title = "Regime Type")) +
  theme(legend.position = "bottom")
dev.off()


png(file="row-democracy-vaccine.png", height=6.5, width=6, units="in", res=300)
ggplot(na.omit(covid.plot), aes(y=people_vaccinated_per_hundred/100, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() + scale_y_continuous(labels = scales::percent_format()) +
  scale_x_log10(labels = c("< $1.00", "$10.00", "$100.00", "$1,000", "$10,000",
                           "$25,000", "$50,000", "$100,000"), 
                breaks=c(1, 10, 100, 1000, 10000, 25000, 50000, 100000)) +
  xlab("GDP per Capita (log scale)") + ylab("Percentage of population with at least one dose of vaccine") + 
  geom_smooth(method="glm", formula=y ~ x, se=F, method.args = list(family="quasibinomial")) +
  ggtitle(label = "Worldwide Vaccination Rates", 
#         subtitle = paste("As of ", max(covid.m$date), " (using latest available data after 2021-08-01)", sep="")) +
          subtitle = "As of September 14, 2021 (using latest available data after August 1, 2021)") + 
  guides(color = guide_legend(title = "Regime Type")) +
  theme(legend.position = "bottom")
dev.off()

write.csv(covid.plot, file="gdp-numbers-merge.csv")


glm.mod <- glm(people_vaccinated_per_hundred/100 ~ log(gdp_per_capita)+democracy, family = "quasibinomial", data = covid.plot)
summary(glm.mod)


########################################
########################################
# Excess mortality analysis
########################################
########################################

# initialize server
rm(list=ls())
# setwd("/pol300")
library(tidyverse)

covid <- read.csv("owid-covid-data.csv")                             # load covid data
#browseURL(url = "https://ourworldindata.org/covid-vaccinations")     # where the data come from
excess <- read.csv("excess-mortality.csv")
#browseURL(url = "https://github.com/dkobak/excess-mortality")        # where the data come from
library(vdemdata)                                                    # need VDEM for democracy data
vdem %>%                                                             # year 2020 only (latest democracy data)
  filter(year==2020) ->
  vdem.s

# what countries from the excess set do we have in VDEM?
unique(excess$Country[excess$Country %in% vdem.s$country_name])
# what countries from the excess set do we NOT have in VDEM?
`%notin%` <- Negate(`%in%`)
unique(excess$Country[excess$Country %notin% vdem.s$country_name])

# what countries from the VDEM set do we not have in excess?
sort(unique(vdem.s$country_name[vdem.s$country_name %notin% excess$Country]))

# change some names for compatibility
vdem.s$country_name[vdem.s$country_name == "United States of America"] <- "United States"
excess$Country[excess$Country == "Czechia"] <- "Czech Republic"

vdem.s.small <- vdem.s %>% select(country_name, v2x_regime)

# merge the two data sets
covid.temp <- left_join(excess, vdem.s.small, by=c("Country" = "country_name"))

# merge in gdp
gdp.numbers <- read.csv("gdp-numbers-merge.csv")
gdp.numbers$location[gdp.numbers$location=="Czechia"] <- "Czech Republic"
# what countries from the excess set do we not have in gdp numbers?
sort(unique(covid.temp$Country[covid.temp$Country %notin% gdp.numbers$location]))
covid.m <- left_join(covid.temp, gdp.numbers, by=c("Country" = "location"))

# classify some countries as democracy
covid.m$democracy <- factor(covid.m$v2x_regime >= 2, 
                            levels=c(FALSE,TRUE), labels=c("dictatorship", "democracy"))
table(covid.m$democracy)
plot(democracy ~ v2x_regime, data=covid.m)

# create small plot data set with only the variables we use
# and omitting democracy missing values
covid.plot <- covid.m %>% 
  filter(is.na(democracy) == F) %>% 
  select(Excess.as...of.annual.baseline, democracy, gdp_per_capita, Country) %>%
  rename(excess_mortality = Excess.as...of.annual.baseline)

na.omit(covid.plot)$Country

# basic plot
ggplot(covid.plot, aes(y=excess_mortality, x=democracy)) +
  geom_boxplot(fill="lightgray") + theme_bw() + xlab("democracy") + ylab("excess mortality rate (% of annual baseline)")

# first bivariate plot
ggplot(covid.plot, aes(y=excess_mortality, x=gdp_per_capita, color=democracy)) +
  geom_point()

# improved aesthetics--but be careful with na.omit!! with great power
# comes great responsibility not to accidentally drop 90% of the data set
ggplot(na.omit(covid.plot), aes(y=excess_mortality, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() +
  scale_x_continuous(labels = scales::dollar_format()) +
  xlab("GDP per Capita") + ylab("excess mortality rate (% of annual baseline)") + geom_smooth(method="lm", formula=y~x, se=F) +
  ggtitle(label = "Excess Mortality Rates", subtitle = "Annual, year 2020")

pdf(file="row-democracy-deaths.pdf", height=6, width = 5.5)
# omit Peru, an outlier, from the fit
ggplot(na.omit(covid.plot), aes(y=excess_mortality, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() +
  scale_x_log10(labels = c("< $1.00", "$10.00", "$100.00", "$1,000", "$5,000", "$10,000",
                           "$25,000", "$50,000", "$100,000"), 
                breaks=c(1, 10, 100, 1000, 5000, 10000, 25000, 50000, 100000)) +
  xlab("GDP per Capita (log scale)") + ylab("Percentage of additional deaths compared with years 2015-2019") + 
  geom_smooth(data = na.omit(covid.plot %>% filter(excess_mortality < 150)), method="lm", formula=y ~ x, se=F) +
  ggtitle(label = "Worldwide Excess Mortality Rate, Year 2020") +
  guides(color = guide_legend(title = "Regime Type")) +
  theme(legend.position = "bottom") + 
  geom_text(data = covid.plot %>% filter(excess_mortality > 150), aes(label = Country), 
            color="black", nudge_x = 0.08)
dev.off()

png(file="row-democracy-deaths.png", height=6.5, width=6, units="in", res=300)
# omit Peru, an outlier, from the fit
ggplot(na.omit(covid.plot), aes(y=excess_mortality, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() +
  scale_x_log10(labels = c("< $1.00", "$10.00", "$100.00", "$1,000", "$5,000", "$10,000",
                           "$25,000", "$50,000", "$100,000"), 
                breaks=c(1, 10, 100, 1000, 5000, 10000, 25000, 50000, 100000)) +
  xlab("GDP per Capita (log scale)") + ylab("Percentage of additional deaths compared with years 2015-2019") + 
  geom_smooth(data = na.omit(covid.plot %>% filter(excess_mortality < 150)), method="lm", formula=y ~ x, se=F) +
  ggtitle(label = "Worldwide Excess Mortality Rate, Year 2020") +
  guides(color = guide_legend(title = "Regime Type")) +
  theme(legend.position = "bottom") + 
  geom_text(data = covid.plot %>% filter(excess_mortality > 150), aes(label = Country), 
            color="black", nudge_x = 0.08)

dev.off()


lin.mod <- lm(excess_mortality ~ log(gdp_per_capita)*democracy, data=covid.plot %>% filter(Country != "Peru"))
summary(lin.mod)
library(car)
linearHypothesis(lin.mod, "1*democracydemocracy + 10*log(gdp_per_capita):democracydemocracy")
linearHypothesis(lin.mod, "1*democracydemocracy + 10.5*log(gdp_per_capita):democracydemocracy")
linearHypothesis(lin.mod, "1*democracydemocracy + 11*log(gdp_per_capita):democracydemocracy")
linearHypothesis(lin.mod, "1*democracydemocracy + 11.5*log(gdp_per_capita):democracydemocracy")
detach(package:car, unload=T)


# use the POLITY measure of democracy
# (not as good--has to come from 2018)
# initialize server
rm(list=ls())
# setwd("/pol300")
library(tidyverse)

covid <- read.csv("owid-covid-data.csv")                             # load covid data
#browseURL(url = "https://ourworldindata.org/covid-vaccinations")     # where the data come from
excess <- read.csv("excess-mortality.csv")
#browseURL(url = "https://github.com/dkobak/excess-mortality")        # where the data come from
library(vdemdata)                                                    # need VDEM for democracy data
vdem %>%                                                             # year 2018 only (latest democracy data)
  filter(year==2018) ->
  vdem.s

# what countries from the excess set do we have in VDEM?
unique(excess$Country[excess$Country %in% vdem.s$country_name])
# what countries from the excess set do we NOT have in VDEM?
`%notin%` <- Negate(`%in%`)
unique(excess$Country[excess$Country %notin% vdem.s$country_name])

# what countries from the VDEM set do we not have in excess?
sort(unique(vdem.s$country_name[vdem.s$country_name %notin% excess$Country]))

# change some names for compatibility
vdem.s$country_name[vdem.s$country_name == "United States of America"] <- "United States"
excess$Country[excess$Country == "Czechia"] <- "Czech Republic"

vdem.s.small <- vdem.s %>% select(country_name, e_polity2)

# merge the two data sets
covid.temp <- left_join(excess, vdem.s.small, by=c("Country" = "country_name"))

# merge in gdp
gdp.numbers <- read.csv("gdp-numbers-merge.csv")
gdp.numbers$location[gdp.numbers$location=="Czechia"] <- "Czech Republic"
# what countries from the excess set do we not have in gdp numbers?
sort(unique(covid.temp$Country[covid.temp$Country %notin% gdp.numbers$location]))
covid.m <- left_join(covid.temp, gdp.numbers, by=c("Country" = "location"))

# classify some countries as democracy
covid.m$democracy <- factor(covid.m$e_polity2 >= 6, 
                            levels=c(FALSE,TRUE), labels=c("dictatorship", "democracy"))
table(covid.m$democracy)
plot(as.numeric(democracy) ~ e_polity2, data=covid.m)

# create small plot data set with only the variables we use
# and omitting democracy missing values
covid.plot <- covid.m %>% 
  filter(is.na(democracy) == F) %>% 
  select(Excess.as...of.annual.baseline, democracy, gdp_per_capita, Country) %>%
  rename(excess_mortality = Excess.as...of.annual.baseline)

na.omit(covid.plot)$Country

# basic plot
ggplot(covid.plot, aes(y=excess_mortality, x=democracy)) +
  geom_boxplot(fill="lightgray") + theme_bw() + xlab("democracy") + ylab("excess mortality rate (% of annual baseline)")

# first bivariate plot
ggplot(covid.plot, aes(y=excess_mortality, x=gdp_per_capita, color=democracy)) +
  geom_point()

# improved aesthetics--but be careful with na.omit!! with great power
# comes great responsibility not to accidentally drop 90% of the data set
ggplot(na.omit(covid.plot), aes(y=excess_mortality, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() +
  scale_x_continuous(labels = scales::dollar_format()) +
  xlab("GDP per Capita") + ylab("excess mortality rate (% of annual baseline)") + geom_smooth(method="lm", formula=y~x, se=F) +
  ggtitle(label = "Excess Mortality Rates", subtitle = "Annual, year 2020")

# omit Peru, an outlier, from the fit
ggplot(na.omit(covid.plot), aes(y=excess_mortality, x=gdp_per_capita, color=democracy)) +
  geom_point(alpha=0.4) + theme_bw() +
  scale_x_log10(labels = c("< $1.00", "$10.00", "$100.00", "$1,000", "$5,000", "$10,000",
                           "$25,000", "$50,000", "$100,000"), 
                breaks=c(1, 10, 100, 1000, 5000, 10000, 25000, 50000, 100000)) +
  xlab("GDP per Capita (log scale)") + ylab("Percentage of additional deaths compared with years 2015-2019") + 
  geom_smooth(data = na.omit(covid.plot %>% filter(excess_mortality < 150)), method="lm", formula=y ~ x, se=F) +
  ggtitle(label = "Worldwide Excess Mortality Rate, Year 2020") +
  guides(color = guide_legend(title = "Regime Type")) +
  theme(legend.position = "bottom") + 
  geom_text(data = covid.plot %>% filter(excess_mortality > 150), aes(label = Country), 
            color="black", nudge_x = 0.08)


lin.mod <- lm(excess_mortality ~ log(gdp_per_capita)*democracy, data=covid.plot %>% filter(Country != "Peru"))
summary(lin.mod)
library(car)
linearHypothesis(lin.mod, "1*democracydemocracy + 10*log(gdp_per_capita):democracydemocracy")
linearHypothesis(lin.mod, "1*democracydemocracy + 10.5*log(gdp_per_capita):democracydemocracy")
linearHypothesis(lin.mod, "1*democracydemocracy + 11*log(gdp_per_capita):democracydemocracy")
linearHypothesis(lin.mod, "1*democracydemocracy + 11.5*log(gdp_per_capita):democracydemocracy")
detach(package:car, unload=T)








# Comparison of raw deaths from COVID
# RoW democracy measure

# initialize server
rm(list=ls())
# setwd("/pol300")
library(tidyverse)

covid <- read.csv("owid-covid-data.csv")                             # load covid data
#browseURL(url = "https://ourworldindata.org/covid-vaccinations")     # where the data come from
library(vdemdata)                                                    # need VDEM for democracy data
vdem %>%                                                             # year 2020 only (latest democracy data)
  filter(year==2020) ->
  vdem.s

# what countries from the COVID set do we have in VDEM?
unique(covid$location[covid$iso_code %in% vdem.s$country_text_id])
`%notin%` <- Negate(`%in%`)
# what countries from the COVID set do we NOT have in VDEM?
unique(covid$location[covid$iso_code %notin% vdem.s$country_text_id])

# what countries from the VDEM set do we not have in COVID?
unique(vdem.s$country_name[vdem.s$country_text_id %notin% covid$iso_code])
vdem.s.small <- vdem.s %>% select(country_text_id, v2x_regime)

# what's the latest date for which data is available?
covid.s <- covid %>% 
  filter(!is.na(total_deaths_per_million)) %>%
  group_by(location) %>%
  filter(date == max(date)) 

# dates of availability
print(covid.s[order(covid.s$date),c("date", "location", 
                                    "total_deaths_per_million")], n=226)

# merge the two data sets
covid.m <- left_join(covid.s, vdem.s.small, by=c("iso_code" = "country_text_id"))

# classify some countries as democracy
covid.m$democracy <- factor(covid.m$v2x_regime >= 2, 
                            levels=c(FALSE,TRUE), labels=c("dictatorship", "democracy"))
table(covid.m$democracy)
plot(democracy ~ v2x_regime, data=covid.m)

# create small plot data set with only the variables we use
# and omitting democracy missing values
covid.plot <- covid.m %>% 
  filter(is.na(democracy) == F) %>% 
  select(total_deaths_per_million, democracy, gdp_per_capita, location)

na.omit(covid.plot)$location

# basic plot
ggplot(covid.plot, aes(y=total_deaths_per_million, x=democracy)) +
  geom_boxplot(width = 0.5) +
  theme_bw() + xlab("democracy") + ylab("Total deaths per million population") +
  xlab("Regime Type")

ggplot(covid.plot, aes(y=total_deaths_per_million/100, x=log(gdp_per_capita), color=democracy)) +
  geom_point() + geom_smooth(formula = y~x, method="loess", se=F)


#####
# basic plot: exclude very low development
#####
png(file="row-deaths-comparison.png", height=5.5, width=6, units="in", res=300)
ggplot(covid.plot %>% filter(gdp_per_capita > 3000), 
       aes(y=total_deaths_per_million, x=democracy, fill=democracy)) +
  geom_boxplot(width = 0.5) +
  theme_bw() + xlab("democracy") + ylab("Total deaths per million population") +
  xlab("Regime Type") + theme(legend.position = "none") +
  ggtitle("Worldwide COVID-19 Deaths", subtitle="Countries with GDP per capita above $3,000, as of September 14, 2021")
dev.off()

pdf(file="row-deaths-comparison.pdf", height=5.5, width=6)
# basic plot: exclude very low development
ggplot(covid.plot %>% filter(gdp_per_capita > 3000), 
       aes(y=total_deaths_per_million, x=democracy, fill=democracy)) +
  geom_boxplot(width = 0.5) +
  theme_bw() + xlab("democracy") + ylab("Total deaths per million population") +
  xlab("Regime Type") + theme(legend.position = "none") +
  ggtitle("Worldwide COVID-19 Deaths", subtitle="Countries with GDP per capita above $3,000, as of September 14, 2021")
dev.off()

# statistical significance
t.test(total_deaths_per_million ~ democracy, data=covid.plot %>% filter(gdp_per_capita >= 3000))